@@ -58,7 +58,10 @@ class ModelAction(ABC):
         # generate string representation replacing format string items interactively
         obj_items=self.__dict__.copy()
         obj_items.update(self.__class__.__dict__)
-        return self.description.format(**obj_items)
+        try:
+            return self.description.format(**obj_items)
+        except KeyError:
+            return self.description
 
     @property
     def description(self):
@@ -228,11 +231,12 @@ class UpdateModelScript(ModelAction):
                     ndiff = diff.pop(0)
                     nextcdiff[1].append(ndiff[2:])
                     old_indx+=1
-                while len(diff)>0 and diff[0][0] == '?':
-                    ndiff = diff.pop(0)
-                # collect new lines to insert
-                while len(diff)>0 and diff[0][0] == '+':
-                    nextcdiff[2].append(diff.pop(0)[2:])
+                while len(diff)>0 and diff[0][0] in ['?', '+']:
+                    if diff[0][0]=='?':
+                        ndiff = diff.pop(0)
+                    else:
+                        # collect new lines to insert
+                        nextcdiff[2].append(diff.pop(0)[2:])
                 cdiff.append(nextcdiff)
             elif old_indx==0 and ndiff.startswith('+'):
                 nextcdiff = [old_indx, [], [ndiff[2:]]]
@@ -524,3 +528,20 @@ class SortAndGroupParams(ModelAction):
     def undo(self):
         self.model.parameters.data=self.old_parameters
         self.old_parameters=[]
+
+class ExchangeModel(ModelAction):
+    influences = ModelInfluence.PARAM|ModelInfluence.DATA|ModelInfluence.SCRIPT
+    name = 'exchange model'
+    description = 'replace model, data and parameter grid from internal storage memory'
+
+    def __init__(self, model, new_model: Model):
+        self.model = model
+        self.new_state = new_model.__getstate__().copy()
+        self.new_state['filename'] = self.model.filename
+        self.old_state = model.__getstate__().copy()
+
+    def execute(self):
+        self.model.__setstate__(self.new_state)
+
+    def undo(self):
+        self.model.__setstate__(self.old_state)
