@@ -13,7 +13,7 @@ MakeClasses - Function that creates the classes (backward comparability).
 '''
 
 import numpy as np
-from genx.gui_logging import iprint
+from genx.core.custom_logging import iprint
 
 class ReflFunction:
     def __init__(self, function, validation_args, validation_kwargs, id=None):
@@ -511,7 +511,7 @@ def MakeClasses(InstrumentParameters=None,
 if __name__=='__main__':
     InstrumentParameters={'probe': 'x-ray', 'wavelength': 1.54, 'coords': 'tth',
                           'I0': 1.0, 'res': 0.001,
-                          'restype': 'no conv', 'respoints': 5, 'resintrange': 2, 'beamw': 0.01,
+                          'restype': 'no conv', 'respoints': 5, 'resintrange': 2.0, 'beamw': 0.01,
                           'footype': 'no corr', 'samplelen': 10.0, 'incangle': 0.0, 'pol': 'uu',
                           'Ibkg': 0.0, 'tthoff': 0.0}
 
